@@ -6,7 +6,7 @@ import argparse
 import yaml
 
 from rest_model_service.helpers import create_app
-from rest_model_service.configuration import Configuration
+from rest_model_service.configuration import ServiceConfiguration
 
 
 def main() -> None:
@@ -21,7 +21,7 @@ def main() -> None:
     try:
         with open(args.configuration_file, "r") as file:
             configuration_dict = yaml.full_load(file)
-        configuration = Configuration(**configuration_dict)
+        configuration = ServiceConfiguration(**configuration_dict)
 
         # create application object, waiting for model creation to finish in order to have all the model endpoints in
         # the OpenAPI document
